@@ -77,12 +77,6 @@
 
 (setq browse-url-browser-function 'mew-browse-url)
 
-(add-hook 'mew-init-hook
-	  (lambda ()
-	    (progn 
-	      (define-key mew-message-mode-map mew-browse-button 'browse-url-at-mouse)
-	      )))
-
 (defvar mew-browse-url-mailto-switch-func nil
   "*Which do you like, nil, 'switch-to-buffer-other-window or 'switch-to-buffer-other-frame ?")
 
@@ -166,7 +160,7 @@
   (message "Browse %s" url)
   (cond
    ((string-match "^mailto:" url)
-    (mew-browse-url-mailto url))
+    (mew-url-mailto url))
    ((and (symbolp mew-ext-prog-url) (fboundp mew-ext-prog-url))
     (funcall mew-ext-prog-url url))
    ((equal mew-ext-prog-url "w3")
@@ -283,8 +277,8 @@ or
 		  (eq cs mew-cs-unknown))
 	  (setq cs mew-cs-autoconv))
 	(when (and (eq cs 'utf-8)
-		   (or (not mew-internal-utf-8p)
-		       (not (featurep 'un-define))))
+		   (not mew-internal-utf-8p)
+		   (not (featurep 'un-define)))
 	  (condition-case nil
 	      (require 'un-define)
 	    (file-error
