@@ -131,6 +131,27 @@ If MUST-HIT is non-nil and no valid cache entry is found, an error occurs."
       (setq mew-cache (nconc mew-cache
 			     (list (mew-cache-entry-make nil nil buf)))))))
 
+(defvar mew-fields-xcc
+  (list mew-fcc: mew-dcc: mew-bcc:
+	mew-resent-fcc: mew-resent-bcc: mew-resent-dcc:))
+
+(defun mew-xinfo-get-xcc (fld msg)
+  (when (or (mew-folder-queuep fld) (mew-folder-postqp fld))
+    (let ((info (concat (mew-expand-folder fld msg) mew-queue-info-suffix))
+	  (headers mew-fields-xcc)
+	  data header addr xinfo)
+      (when (and (file-readable-p info)
+		 (setq data (aref (mew-lisp-load info) 0)))
+	(with-temp-buffer
+	  (insert data)
+	  (goto-char (point-min))
+	  (while headers
+	    (setq header (car headers))
+	    (setq headers (cdr headers))
+	    (when (setq addr (mew-header-get-value header))
+	      (setq xinfo (cons (format "%s %s\n" header addr) xinfo)))))
+	(nreverse xinfo)))))
+
 (defun mew-cache-message (fld msg &optional unlimit no-err)
   "Cache the message specified by FLD and MSG.
 If an invalid message are cached, deletes it and caches the message again.
@@ -182,6 +203,7 @@ if decode fails."
 	 (message "MIME decoding for %s/%s aborted" fld msg)
 	 (throw 'return (setq cache nil))))
       (mew-ainfo-set-icon msg)
+      (mew-xinfo-set-info (append (mew-xinfo-get-info) (mew-xinfo-get-xcc fld msg)))
       (mew-decode-syntax-set))
     ;;
     (set-buffer cbuf)
