@@ -52,6 +52,8 @@
 ;;; Part handler
 ;;;
 
+;; see also mew-summary-execute-external().
+
 (defun mew-mime-part (cache fullpart nums)
   ;; called in Message buffer
   ;; if nums is nil, it means singlepart.
@@ -65,25 +67,26 @@
 	 (fname   (mew-syntax-get-filename cdpl ctl))
 	 (cd      (mew-syntax-get-cd syntax))
 	 (params  (mew-syntax-get-params ctl))
-	 (program (mew-ctdb-prog (mew-ctdb-by-ct ct))))
+	 (program (mew-ctdb-prog (mew-ctdb-by-ct ct)))
+	 func2)
+    (when (listp program)
+      (setq func2 (nth 1 program))
+      (setq program (nth 0 program)))
     (cond
+     ((null program)
+      (mew-mime-function func2 cache begin end ct cte cd fname))
      ((symbolp program)
       (when (fboundp program)
 	(cond
 	 ((eq program 'mew-mime-message/rfc822)
 	  (funcall program cache syntax)) ;; for recursive MIME
 	 ((eq program 'mew-mime-application/octet-stream)
-	  (funcall program cache begin end params ct cte fname))
+	  (funcall program cache begin end params ct cte cd fname))
+	 ((mew-ct-imagep ct)
+	  (funcall program cache begin end params fname ct cte))
 	 (t
 	  (funcall program cache begin end params)))))
-     ((and (listp program) (nth 0 program) (symbolp (nth 0 program)))
-      (when (fboundp (nth 0 program))
-	(if (mew-ct-imagep ct)
-	    (funcall (nth 0 program) cache begin end params fname ct cte)
-	  (if (eq (nth 0 program) 'mew-mime-application/octet-stream)
-	      (funcall (nth 0 program) cache begin end params ct cte fname (nth 1 program))
-	    (funcall (nth 0 program) cache begin end params)))))
-     ((and (listp program) (nth 0 program) (stringp (nth 0 program)))
+     (t ;; string
       (insert " ######  ######  #######  #####  ######     #    #     #\n"
 	      " #     # #     # #     # #     # #     #   # #   ##   ##\n"
 	      " #     # #     # #     # #       #     #  #   #  # # # #\n"
@@ -97,31 +100,45 @@
       (mew-insert "Size:\t\t%d bytes\n" (mew-region-bytes begin end cache))
       (mew-insert "Filename:\t%s\n" fname)
       (mew-insert "Description:\t%s\n" cd)
-      (mew-insert "Program:\t%s\n" (nth 0 program))
+      (mew-insert "Program:\t%s\n" program)
       (insert "\n")
       (mew-mime-part-messages t)))))
 
+(defun mew-mime-function (func cache begin end &optional ct cte cd fname)
+  (insert " ####### #     # #     #  #####  #######   ###   ####### #     #\n"
+	  " #       #     # ##    # #     #    #       #    #     # ##    #\n"
+	  " #       #     # # #   # #          #       #    #     # # #   #\n"
+	  " #####   #     # #  #  # #          #       #    #     # #  #  #\n"
+	  " #       #     # #   # # #          #       #    #     # #   # #\n"
+	  " #       #     # #    ## #     #    #       #    #     # #    ##\n"
+	  " #        #####  #     #  #####     #      ###   ####### #     #\n"
+	  "\n\n")
+  (mew-insert "Content-Type:\t%s\n" ct)
+  (mew-insert "Encoding:\t%s\n" cte)
+  (mew-insert "Size:\t\t%d bytes\n" (mew-region-bytes begin end cache))
+  (mew-insert "Filename:\t%s\n" fname)
+  (mew-insert "Description:\t%s\n" cd)
+  (mew-insert "Function:\t%s\n" func)
+  (insert "\n")
+  (mew-mime-part-messages func))
+
 (defun mew-mime-part-messages (prog)
   (cond
    ((and prog (fboundp prog))
     (mew-insert-manual
-     "To execute this function, type "
+     "To execute an external function, type "
      "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"
      "\n"))
    (prog
     (mew-insert-manual
-     "To execute this external command, type "
+     "To execute an external command, type "
      "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"
      "\n")))
   (mew-insert-manual
    "To save this part, type "
    "'\\<mew-summary-mode-map>\\[mew-summary-save]'.\n"
    "To insert this part in Message mode, type "
-   "'\\<mew-summary-mode-map>\\[mew-summary-display-asis]'.\n"
-   "To execute a specified external command, type "
-   "'\\<mew-summary-mode-map>\\[mew-summary-execute-command]'.\n"
-   "To display this part as a specified Content-Type:, type "
-   "'\\[universal-argument] \\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"))
+   "'\\<mew-summary-mode-map>\\[mew-summary-display-asis]'.\n"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -145,30 +162,6 @@
 	(goto-char (point-min))
 	(mew-message-narrow-to-page)))))
 
-(defun mew-mime-text/plain-ext (cache begin end &optional params)
-  "To call the Text/Plain function for a text attachment whose
-Content-Type: is Application/Octet-Stream."
-  ;; called in Message buffer
-  (when (> end begin)
-    (mew-erase-buffer)
-    ;; We need to keep properties (e.g. citation color)
-    ;; in a message cache.
-    ;; This must be "insert-buffer-substring".
-    (insert-buffer-substring cache begin end)
-    (unless (and mew-inherit-ct (mew-ct-textp mew-inherit-ct)
-		 (or (mew-cache-dinfo-get-decode-broken cache)
-		     (mew-charset-to-cs
-		      (mew-syntax-get-param params "charset"))))
-      (mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
-    (when mew-insert-final-newline
-      (save-excursion
-	(goto-char (point-max))
-	(if (not (bolp)) (insert "\n"))))
-    ;; Page breaks
-    (when mew-break-pages
-      (goto-char (point-min))
-      (mew-message-narrow-to-page))))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Text/Enriched
@@ -234,74 +227,61 @@ Content-Type: is Application/Octet-Stream."
     (insert "\n")
     (mew-mime-part-messages t)))
 
-(defun mew-mime-text/html-ext (cache begin end &optional params)
-  ;; called in Message buffer
-  (cond
-   ((and (symbolp mew-prog-text/html-ext) (fboundp mew-prog-text/html-ext))
-    (message "Displaying HTML...")
-    (save-excursion
-      (mew-erase-buffer)
-      ;; We need to keep composite properties of charset.
-      ;; This must be "insert-buffer-substring".
-      (insert-buffer-substring cache begin end)
-      (unless (and mew-inherit-ct (mew-ct-textp mew-inherit-ct)
-		   (or (mew-cache-dinfo-get-decode-broken cache)
-		       (mew-charset-to-cs
-			(mew-syntax-get-param params "charset"))))
-	(mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
-      (funcall mew-prog-text/html-ext (point-min) (point-max)))
-    (message "Displaying HTML...done"))
-   ((stringp mew-prog-text/html-ext)
-    (when (> end begin)
-      (let ((file (format mew-format-html (mew-make-temp-name)))
-	    (orig mew-prog-text/html-ext-arg)
-	    arg wcs esqp)
-	(save-excursion
-	  (message "Displaying Text/Html...")
-	  (set-buffer cache)
-	  (while orig
-	    (if (string-match "%s" (car orig))
-		(progn
-		  (setq arg (cons (format (car orig) file) arg))
-		  (setq esqp t))
-	      (setq arg (cons (car orig) arg)))
-	    (setq orig (cdr orig)))
-	  (unless esqp (setq arg (cons file arg)))
-	  (setq arg (nreverse arg))
-	  (setq wcs (mew-text/html-detect-cs begin end params))
-	  (unless (mew-coding-system-p wcs)
-	    (setq wcs (mew-charset-to-cs
-		       (mew-syntax-get-param params "charset"))))
-	  (mew-frwlet
-	   mew-cs-dummy wcs
-	   (write-region begin end file nil 'no-msg)
-	   (apply 'mew-start-process-disp
-		  mew-prog-text/html-ext nil mew-prog-text/html-ext arg))
-	  (message "Displaying Text/Html...done")))))))
-
-(defun mew-text/html-detect-cs (begin end params)
-  (let ((cs (mew-charset-to-cs (mew-syntax-get-param params "charset")))
-	(case-fold-search t))
+(defun mew-text/html-detect-cs (begin end)
+  (let ((case-fold-search t))
     (save-excursion
       (goto-char begin)
-      (cond
-       ((or (re-search-forward
-	     (concat "<meta[ \t]+http-equiv=\"?content-type\"?[ \t]"
-		     "+content=\"[^;]+"
-		     ";[ \t]*charset=\"?\\([^\"]+\\)\"?[ \t]*/?>")
-	     (min end (+ begin 1024)) t)
-	    (re-search-forward
-	     (concat "<meta[ \t]+content=\"[^;]+"
-		     ";[ \t]*charset=\"?\\([^\"]+\\)\"?"
-		     "[ \t]+http-equiv=\"?content-type\"?[ \t]*/?>")
-	     (min end (+ begin 1024)) t))
-	(mew-charset-to-cs (mew-match-string 1)))
-       (cs cs)
-       (t  ;; charset eq "us-ascii", cs is nil.
-	(if mew-decode-broken ;; xxx
-	    (mew-charset-to-cs (mew-charset-guess-region begin end))
-	  ;; this text is no decoded.
-	  mew-cs-text-for-write))))))
+      (when (or (re-search-forward
+		 (concat "<meta[ \t]+http-equiv=\"?content-type\"?[ \t]"
+			 "+content=\"[^;]+"
+			 ";[ \t]*charset=\"?\\([^\"]+\\)\"?[ \t]*/?>")
+		 (min end (+ begin 1024)) t)
+		(re-search-forward
+		 (concat "<meta[ \t]+content=\"[^;]+"
+			 ";[ \t]*charset=\"?\\([^\"]+\\)\"?"
+			 "[ \t]+http-equiv=\"?content-type\"?[ \t]*/?>")
+		 (min end (+ begin 1024)) t)
+		(re-search-forward
+		 "<\\?xml.*encoding=['\"]\\([^'\"]+\\)['\"] *\\?>"
+		 (min end (+ begin 1024)) t))
+	(mew-charset-to-cs (mew-match-string 1))))))
+
+(defun mew-mime-text/html-ext (cache begin end &optional params)
+  (mew-mime-markup-language-ext
+   mew-prog-text/html-ext cache begin end params "HTML" mew-format-html))
+
+(defun mew-mime-markup-language-ext (program cache begin end params tag form)
+  ;; called in Message buffer
+  (when (> end begin)
+    (let ((file (format form (mew-make-temp-name)))
+	  orig args wcs esqp)
+      (if (listp program) (mew-set '(program orig nil) program))
+      (save-excursion
+	(message "Displaying %s..." tag)
+	(set-buffer cache)
+	;; converting "%s"
+	(while orig
+	  (if (string-match "%s" (car orig))
+	      (progn
+		(setq args (cons (format (car orig) file) args))
+		(setq esqp t))
+	    (setq args (cons (car orig) args)))
+	  (setq orig (cdr orig)))
+	(unless esqp (setq args (cons file args)))
+	(setq args (nreverse args))
+	;; charset check
+	(setq wcs (mew-text/html-detect-cs begin end))
+	;; note that application/xml may have the charset parameter
+	(unless (mew-coding-system-p wcs)
+	  (setq wcs (mew-charset-to-cs
+		     (mew-syntax-get-param params "charset"))))
+	(unless (mew-coding-system-p wcs)
+	  (setq wcs mew-cs-text-for-write))
+	(mew-frwlet
+	 mew-cs-dummy wcs
+	 (write-region begin end file nil 'no-msg)
+	 (apply 'mew-start-process-disp program nil program args))
+	(message "Displaying %s...done" tag)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -335,66 +315,8 @@ Content-Type: is Application/Octet-Stream."
     (mew-mime-part-messages t)))
 
 (defun mew-mime-text/xml-ext (cache begin end &optional params)
-  ;; called in Message buffer
-  (cond
-   ((and (symbolp mew-prog-text/xml-ext) (fboundp mew-prog-text/xml-ext))
-    (message "Displaying XML...")
-    (save-excursion
-      (mew-erase-buffer)
-      ;; We need to keep composite properties of charset.
-      ;; This must be "insert-buffer-substring".
-      (insert-buffer-substring cache begin end)
-      (unless (and mew-inherit-ct (mew-ct-textp mew-inherit-ct)
-		   (or (mew-cache-dinfo-get-decode-broken cache)
-		       (mew-charset-to-cs
-			(mew-syntax-get-param params "charset"))))
-	(mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
-      (funcall mew-prog-text/xml-ext (point-min) (point-max)))
-    (message "Displaying XML...done"))
-   ((stringp mew-prog-text/xml-ext)
-    (when (> end begin)
-      (let ((file (format mew-format-xml (mew-make-temp-name)))
-	    (orig mew-prog-text/xml-ext-arg)
-	    arg wcs esqp)
-	(save-excursion
-	  (message "Displaying Text/Xml...")
-	  (set-buffer cache)
-	  (while orig
-	    (if (string-match "%s" (car orig))
-		(progn
-		  (setq arg (cons (format (car orig) file) arg))
-		  (setq esqp t))
-	      (setq arg (cons (car orig) arg)))
-	    (setq orig (cdr orig)))
-	  (unless esqp (setq arg (cons file arg)))
-	  (setq arg (nreverse arg))
-	  (setq wcs (mew-text/xml-detect-cs begin end params))
-	  (unless (mew-coding-system-p wcs)
-	    (setq wcs (mew-charset-to-cs
-		       (mew-syntax-get-param params "charset"))))
-	  (mew-frwlet
-	   mew-cs-dummy wcs
-	   (write-region begin end file nil 'no-msg)
-	   (apply 'mew-start-process-disp
-		  mew-prog-text/xml-ext nil mew-prog-text/xml-ext arg))
-	  (message "Displaying Text/Xml...done")))))))
-
-(defun mew-text/xml-detect-cs (begin end params)
-  (let ((cs (mew-charset-to-cs (mew-syntax-get-param params "charset")))
-	(case-fold-search t))
-    (save-excursion
-      (goto-char begin)
-      (cond
-       ((re-search-forward
-	 "<\\?xml.*encoding=['\"]\\([^'\"]+\\)['\"] *\\?>"
-	 (min end (+ begin 1024)) t)
-	(mew-charset-to-cs (mew-match-string 1)))
-       (cs cs)
-       (t  ;; charset eq "us-ascii", cs is nil.
-	(if mew-decode-broken
-	    (mew-charset-to-cs (mew-charset-guess-region begin end))
-	  ;; this text is no decoded.
-	  mew-cs-text-for-write))))))
+  (mew-mime-markup-language-ext
+   mew-prog-text/xml-ext cache begin end params "XML" mew-format-xml))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -427,42 +349,8 @@ Content-Type: is Application/Octet-Stream."
     (mew-mime-part-messages t)))
 
 (defun mew-mime-application/xml-ext (cache begin end &optional params)
-  ;; called in Message buffer
-  (cond
-   ((and (symbolp mew-prog-application/xml-ext) (fboundp mew-prog-application/xml-ext))
-    (message "Displaying XML...")
-    (save-excursion
-      (mew-erase-buffer)
-      ;; We need to keep composite properties of charset.
-      ;; This must be "insert-buffer-substring".
-      (insert-buffer-substring cache begin end)
-      (funcall mew-prog-application/xml-ext (point-min) (point-max)))
-    (message "Displaying XML...done"))
-   ((stringp mew-prog-application/xml-ext)
-    (when (> end begin)
-      (let ((file (format "%s.xml" (mew-make-temp-name)))
-	    (orig mew-prog-application/xml-ext-arg)
-	    arg wcs esqp)
-	(save-excursion
-	  (message "Displaying Application/Xml...")
-	  (set-buffer cache)
-	  (while orig
-	    (if (string-match "%s" (car orig))
-		(progn
-		  (setq arg (cons (format (car orig) file) arg))
-		  (setq esqp t))
-	      (setq arg (cons (car orig) arg)))
-	    (setq orig (cdr orig)))
-	  (unless esqp (setq arg (cons file arg)))
-	  (setq arg (nreverse arg))
-	  (setq wcs mew-cs-binary)
-	  (mew-frwlet
-	   mew-cs-dummy wcs
-	   (write-region begin end file nil 'no-msg)
-	   (apply 'mew-start-process-disp
-		  mew-prog-application/xml-ext nil
-		  mew-prog-application/xml-ext arg))
-	  (message "Displaying Application/Xml...done")))))))
+  (mew-mime-markup-language-ext
+   mew-prog-application/xml-ext cache begin end params "XML" mew-format-xml))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -489,14 +377,20 @@ Content-Type: is Application/Octet-Stream."
       (insert "\n")
       (mew-mime-part-messages t))))
 
-(defun mew-mime-image/*-ext (cache begin end &optional params fname)
+(defun mew-mime-image/*-ext (cache begin end &optional params fname ct cte)
   (let ((file (mew-make-temp-name fname)))
     (save-excursion
       (set-buffer cache)
       (mew-flet
        (write-region begin end file nil 'no-msg)))
-    (mew-mime-start-process
-     mew-prog-image/*-ext mew-prog-image/*-ext-arg file)))
+    (mew-mime-image-ext file)))
+
+(defun mew-mime-image-ext (file)
+  (let ((program mew-prog-image/*-ext)
+	args)
+    (if (listp program)
+	(mew-set '(program args nil) program))
+    (mew-mime-start-process program args file)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -538,7 +432,7 @@ Content-Type: is Application/Octet-Stream."
 ;;; Application/Octet-Stream
 ;;;
 
-(defun mew-mime-application/octet-stream (cache begin end &optional params ct cte fl func)
+(defun mew-mime-application/octet-stream (cache begin end &optional params ct cte cd fl)
   (insert " ######    ###   #     #    #    ######  #     #\n"
 	  " #     #    #    ##    #   # #   #     #  #   #\n"
 	  " #     #    #    # #   #  #   #  #     #   # #\n"
@@ -555,9 +449,13 @@ Content-Type: is Application/Octet-Stream."
      (mapconcat (lambda (x) (concat (nth 0 x) "=" (nth 1 x))) params ", ")))
   (mew-insert "Size:\t\t%d bytes\n" (mew-region-bytes begin end cache))
   (mew-insert "Filename:\t%s\n" fl)
-  (when func (mew-insert "Function:\t%s\n" func))
+  (mew-insert "Description:\t%s\n" cd)
+  (mew-insert-manual
+   "\nTo specify appropriate Content-Type: \n"
+   "and execute an internal/external function/command, "
+   "type \\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n")
   (insert "\n")
-  (mew-mime-part-messages func))
+  (mew-mime-part-messages nil))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -580,24 +478,8 @@ Content-Type: is Application/Octet-Stream."
   (mew-mime-application/msoffice
    mew-prog-application/rtf cache begin end parameter))
 
-(defun mew-mime-application/msword-ext (cache begin end &optional parameter)
-  (save-excursion
-    (mew-erase-buffer)
-    (mew-mime-application/msword cache begin end parameter)))
-
-(defun mew-mime-application/msexcel-ext (cache begin end &optional parameter)
-  (save-excursion
-    (mew-erase-buffer)
-    (mew-mime-application/msexcel cache begin end parameter)))
-
-(defun mew-mime-application/mspowerpoint-ext (cache begin end &optional parameter)
-  (save-excursion
-    (mew-erase-buffer)
-    (mew-mime-application/mspowerpoint cache begin end parameter)))
-
 (defun mew-mime-application/rtf-ext (cache begin end &optional parameter)
   (save-excursion
-    (mew-erase-buffer)
     (mew-mime-application/rtf cache begin end parameter)))
 
 (defun mew-mime-application/msoffice (prog cache begin end &optional parameter)
@@ -621,6 +503,7 @@ Content-Type: is Application/Octet-Stream."
 	  (insert "\n")
 	  (mew-mime-part-messages nil))
       (message "Displaying an MS document...")
+      (mew-erase-buffer)
       (setq file1 (mew-make-temp-name))
       (save-excursion
 	(set-buffer cache)
