@@ -61,7 +61,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     ("+language=en" "+batchmode=off")
     ("--decrypt")))
 
-(defconst mew-prog-pgps-arg
+(defvar mew-prog-pgps-arg ;; local binding
   '(("-sba" "+language=en" "+batchmode=off")
     ("-ba" "+language=en" "+batchmode=off")
     ("-sba" "+language=en" "+batchmode=off")
@@ -100,9 +100,9 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     " \\(.*\\) signature from \"\\(.*\\)\""))
 
 (defconst mew-pgp-msg-key-id
-  '("Key ID \\(\\S +\\) not found"
-    ": \\(0x[a-zA-Z0-9]+\\)"
-    ": \\(0x[a-zA-Z0-9]+\\)"
+  '("Key ID \\([a-zA-Z0-9]+\\) not found"
+    ": 0x\\([a-zA-Z0-9]+\\)"
+    ": 0x\\([a-zA-Z0-9]+\\)"
     "key ID \\([a-zA-Z0-9]+\\)"))
 
 (defconst mew-pgp-msg-bad-pass
@@ -320,10 +320,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 		(goto-char (point-min))
 		(if (not (re-search-forward (mew-pgp-get mew-pgp-msg-key-id) nil t))
 		    (setq keyid "not found")
-		  (setq keyid (mew-match-string 1))
-		  (if (eq mew-pgp-ver mew-pgp-ver2) ;; xxx
-		      (setq keyid (concat "0x" keyid))))
-		(setq ret (concat mew-pgp-result-pubkey " ID = " keyid)))
+		  (setq keyid (format "0x%s"(mew-match-string 1))))
+		(setq ret (concat mew-pgp-result-pubkey ": ID = " keyid)))
 	    (goto-char (point-min))
 	    (if (search-forward (mew-pgp-get mew-pgp-msg-no-keyring) nil t)
 		(setq ret mew-pgp-result-pubring)
@@ -349,7 +347,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	(setq ret (concat ret (mew-match-string 2))))
       ;; xxx
       (goto-char (point-min))
-      (if (search-forward "not certified with enough" nil t)
+      (if (re-search-forward "not certified with \\(enough\\|sufficiently\\)" nil t)
 	  (setq ret (concat ret " MARGINAL"))
 	(goto-char (point-min))
 	(if (search-forward "not trusted" nil t)
@@ -475,6 +473,13 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;; PGP signing
 ;;;
 
+(defun mew-pgp-canonicalize ()
+  (save-excursion
+    (goto-char (point-min))
+    (while (re-search-forward "[ \t]+$" nil t)
+      (replace-match "" nil t)
+      (forward-line))))
+
 (defun mew-pgp-get-micalg ()
   (let ((micalg (mew-pgp-get mew-pgp-micalg)) alg)
     (if (/= mew-pgp-ver mew-pgp-verg)
@@ -1000,7 +1005,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;;
 
 (defun mew-attach-pgp-public-key ()
-  "Extract the PGP key for the inputted user on '.'. in attachments"
+  "Extract the PGP key for the specified user on '.'. in attachments"
   (interactive)
   (if (not (mew-attach-not-line012-1))
       (message "Cannot link here")
@@ -1149,7 +1154,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 	(setq xmew (mew-header-get-value mew-x-mew:)))
       (cond
        ((and xmew
-	     (string-match "key. ID = \\(0x[0-9a-fA-F]+\\)" xmew nil)
+	     (string-match " ID = \\(0x[0-9a-fA-F]+\\)" xmew nil)
 	     (setq keyid (mew-match-string 1 xmew)))
 	(if (y-or-n-p (format "Fetch the PGP public key for %s? " keyid))
 	    (mew-pgp-fetch-key-from-pks keyid)))
