@@ -28,7 +28,8 @@
     "user" "auth" "auth-list" "key" "passwd" "account"
     "size" "truncated" "get-body"
     "flush" "no-msg" "msgdb" "done" "dispatched" "error"
-    "body-lines" "delete"))
+    "body-lines" "delete" "case"
+    "thread-info" "status-buf"))
 
 (mew-info-defun "mew-pop-" mew-pop-info-list)
 
@@ -72,7 +73,7 @@
   (or (mew-pop-get-ssh-process pnm) (mew-pop-get-ssl-process pnm)))
 
 (defun mew-pop-command-capa (pro pnm)
-  (mew-net-status (mew-pop-get-bnm pnm)
+  (mew-net-status (mew-pop-get-status-buf pnm)
 		  "Auth'ing"
 		  nil
 		  (mew-pop-secure-p pnm))
@@ -175,7 +176,7 @@
     (mew-pop-command-quit2 pro pnm)))
 
 (defun mew-pop-command-list (pro pnm)
-  (mew-net-status (mew-pop-get-bnm pnm)
+  (mew-net-status (mew-pop-get-status-buf pnm)
 		  "Checking"
 		  nil
 		  (mew-pop-secure-p pnm))
@@ -334,7 +335,7 @@
 
 (defun mew-pop-command-dels (pro pnm)
   (mew-net-status1
-   (mew-pop-get-bnm pnm) "Deleting"
+   (mew-pop-get-status-buf pnm) "Deleting"
    (mew-pop-get-dttl pnm) (mew-pop-get-dcnt pnm) (mew-pop-secure-p pnm))
   (let ((directive (mew-pop-get-directive pnm))
 	(dels (mew-pop-get-dels pnm))
@@ -369,7 +370,7 @@
       (mew-pop-command-retr pro pnm)))))
 
 (defun mew-pop-command-retr (pro pnm)
-  (mew-net-status2 (mew-pop-get-bnm pnm)
+  (mew-net-status2 (mew-pop-get-status-buf pnm)
 		   (mew-pop-get-rttl pnm)
 		   (mew-pop-get-rcnt pnm)
 		   (nth 2 (car (mew-pop-get-rtrs pnm)))
@@ -394,7 +395,7 @@
      ((and (eq directive 'scan) (not get-body))
       (mew-pop-set-truncated pnm t)
       (mew-pop-process-send-string pro "TOP %s 0" num))
-     ((or (= lim 0) (< (string-to-int siz) lim))
+     ((or (= lim 0) (< (string-to-number siz) lim))
       (mew-pop-set-truncated pnm nil)
       (mew-pop-process-send-string pro "RETR %s" num))
      (t
@@ -413,7 +414,8 @@
 	 (del  (nth 3 rtr))
 	 (fld-msg (nth 4 rtr))
 	 (truncated (mew-pop-get-truncated pnm))
-	 fld msg vec file msg-file lmsg mark)
+	 (case (mew-pop-get-case pnm))
+	 fld msg vec file msg-file lmsg mark folder)
     (cond
      ((null fld-msg)
       (setq fld (mew-pop-get-bnm pnm)))
@@ -422,6 +424,7 @@
      ((listp fld-msg)
       (mew-set '(fld msg) fld-msg)
       (setq lmsg msg)))
+    (setq folder (mew-case:folder-folder fld))
     ;; deleting +OK
     (goto-char (point-min))
     (forward-line)
@@ -435,10 +438,12 @@
     (goto-char (point-min))
     (cond
      (truncated
-      (mew-header-insert-xmu uid siz t))
+      (mew-header-insert-xmu uid siz t (and (eq directive 'inc)
+					    (or (mew-pop-get-case pnm)
+						mew-case-default))))
      ((eq directive 'scan)
       (mew-header-insert-xmu uid siz nil))
-     ((and (eq directive 'get) (mew-folder-popp (mew-case:folder-folder fld)))
+     ((and (eq directive 'get) (mew-folder-popp folder))
       (mew-header-insert-xmu uid siz nil)))
     (catch 'write-error
       (condition-case nil
@@ -450,6 +455,7 @@
 	 (mew-pop-command-quit pro pnm)
 	 (throw 'write-error nil)))
       (mew-set-file-modes file)
+      (mew-set-file-type file)
       (mew-pop-set-rcnt pnm (1+ (mew-pop-get-rcnt pnm)))
       ;;
       (mew-set-buffer-multibyte t)
@@ -457,7 +463,11 @@
       (mew-scan-set-folder vec fld)
       (mew-scan-set-message vec msg)
       (if (or (eq directive 'inc) (eq directive 'scan))
-	  (setq mark (mew-scan-inbox-action vec)))
+	  (setq mark (mew-scan-inbox-action vec case)))
+      (if (and mark
+	       (eq directive 'scan)
+	       (not (memq mark (list mew-mark-delete mew-mark-unlink))))
+	  (setq mark nil))
       (mew-scan-body vec)
       (mew-set-buffer-multibyte nil)
       (mew-scan-insert-line fld vec width lmsg mark)
@@ -637,7 +647,8 @@
 	 (pnm (mew-pop-info-name case))
 	 (buf (get-buffer-create (mew-pop-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshname sshpro sslname sslpro lport tls)
+	 process sshname sshpro sslname sslpro lport tls
+	 thread-info to-buf)
     (if (mew-pop-get-process pnm)
 	(message "Another POP process is running. Try later")
       (cond
@@ -682,11 +693,13 @@
 	(mew-pop-set-status pnm "greeting")
 	(mew-pop-set-directive pnm directive)
 	(mew-pop-set-bnm pnm bnm)
+	(mew-pop-set-status-buf pnm bnm)
 	(mew-pop-set-rcnt pnm 1)
 	(mew-pop-set-dcnt pnm 1)
 	(mew-pop-set-rttl pnm 0)
 	(mew-pop-set-dttl pnm 0)
 	(mew-pop-set-size pnm (mew-pop-size case))
+	(mew-pop-set-case pnm case)
 	(mew-pop-set-body-lines pnm (mew-pop-body-lines case))
 	(cond
 	 ((eq directive 'biff)
@@ -697,7 +710,15 @@
 	  (mew-pop-set-delete pnm (mew-pop-delete case)))
 	 ((eq directive 'get)
 	  (mew-sinfo-set-unread-mark (mew-get-unread-mark bnm))
-	  (mew-pop-set-refs pnm (nth 0 args)))
+	  (mew-pop-set-refs pnm (nth 0 args))
+	  (setq thread-info (nth 1 args))
+	  (mew-pop-set-thread-info pnm thread-info)
+	  (setq to-buf (nth 0 thread-info))
+	  (when to-buf
+	    (mew-pop-set-status-buf pnm to-buf)
+	    (save-excursion
+	      (set-buffer to-buf)
+	      (mew-summary-lock process "POPing" (or sshpro sslpro)))))
 	 ((eq directive 'scan)
 	  (mew-pop-set-range pnm (nth 0 args))
 	  (mew-pop-set-get-body pnm (nth 1 args))
@@ -741,7 +762,7 @@
      (mew-set-buffer-multibyte nil)
      (insert string)
      (when (string= status "retr")
-       (mew-net-status2 (mew-pop-get-bnm pnm)
+       (mew-net-status2 (mew-pop-get-status-buf pnm)
 			(mew-pop-get-rttl pnm)
 			(mew-pop-get-rcnt pnm)
 			(nth 2 (car (mew-pop-get-rtrs pnm)))
@@ -790,7 +811,8 @@
 	 (done (mew-pop-get-done pnm))
  	 (error (mew-pop-get-error pnm))
 	 (file (mew-expand-folder bnm mew-pop-msgid-file))
-	 (buf (process-buffer process)))
+	 (buf (process-buffer process))
+	 (thread-info (mew-pop-get-thread-info pnm)))
     (mew-pop-debug "POP SENTINEL" event)
     (set-process-buffer process nil)
     (set-buffer bnm)
@@ -821,6 +843,7 @@
 	       "%d message retrieved. %d messages are left due to an error"
 	       (- rttl lefts) lefts)
 	      (mew-summary-folder-cache-save))))
+      (if thread-info (mew-summary-retrieve-message-for-thread thread-info))
       (cond
        (error 
  	;; retain the error message
@@ -879,7 +902,7 @@
 	 (t
 	  (mew-pop-message pnm "%d messages deleted" dttl))))))
     ;;
-    (mew-net-status-clear bnm)
+    (mew-net-status-clear (mew-pop-get-status-buf pnm))
     (mew-info-clean-up pnm)
     (set-buffer-modified-p nil)
     (mew-summary-unlock)
@@ -891,7 +914,7 @@
       (run-hooks 'mew-pop-sentinel-non-biff-hook))
     (run-hooks 'mew-pop-sentinel-hook)
     (when (and mew-auto-flush-queue flush)
-      (mew-smtp-flush-queue mew-case-output))))
+      (mew-smtp-flush-queue mew-case))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -899,7 +922,7 @@
 ;;;
 
 (defun mew-pop-biff ()
-  (let* ((case mew-case-input)
+  (let* ((case mew-case)
 	 (inbox (mew-proto-inbox-folder nil case))
 	 (case:inbox (mew-case-folder case inbox))
 	 (tag (mew-pop-passtag2 case))
@@ -915,7 +938,7 @@
 (defun mew-pop-check ()
   "See if messages are arrived by POP."
   (interactive)
-  (let* ((case mew-case-input)
+  (let* ((case mew-case)
 	 (inbox (mew-proto-inbox-folder nil case))
 	 (case:inbox (mew-case-folder case inbox)))
     (when (get-buffer case:inbox)
