@@ -5,11 +5,47 @@
 
 ;;; Code:
 
-;;
-;; MIME setting
-;;
+;;;
+;;; Office
+;;;
 
-(defvar mew-prog-plain    '(mew-mime-text/plain mew-mime-text/plain-ext))
+(defvar mew-prog-application/msword "wvHtml")
+(defvar mew-prog-application/msexcel "xlhtml")
+(defvar mew-prog-application/mspowerpoint "ppthtml")
+(defvar mew-prog-application/rtf "rtf2html")
+(defvar mew-prog-msword-ext "ooffice")
+(defvar mew-prog-msexcel-ext "ooffice")
+(defvar mew-prog-mspowerpoint-ext "ooffice")
+
+;;;
+;;; Text/Html, Application/Xml
+;;;
+
+(defvar mew-format-html "%s.html")
+(defvar mew-format-xml  "%s.xml")
+
+(defvar mew-prog-text/html           'mew-mime-text/html-w3m) ;; See w3m.el
+(defvar mew-prog-text/html-ext       '("mozilla" ("-remote" "openFile(%s)") t))
+
+(defvar mew-prog-text/xml            'mew-mime-text/html-w3m) ;; See w3m.el
+(defvar mew-prog-text/xml-ext        '("mozilla" ("-remote" "openFile(%s)") t))
+
+(defvar mew-prog-application/xml     nil)
+(defvar mew-prog-application/xml-ext '("mozilla" ("-remote" "openFile(%s)") t))
+
+
+;;;
+;;; Image
+;;; 
+
+(defvar mew-prog-image/*         'mew-mime-image/*)
+(defvar mew-prog-image/*-ext     '("display" ("-geometry" "+0+0")))
+
+;;;
+;;; MIME setting
+;;;
+
+(defvar mew-prog-plain    'mew-mime-text/plain)
 (defvar mew-prog-html     '(mew-mime-text/html mew-mime-text/html-ext))
 (defvar mew-prog-xml      '(mew-mime-text/xml  mew-mime-text/xml-ext))
 (defvar mew-prog-enriched 'mew-mime-text/enriched)
@@ -34,53 +70,25 @@
 (defvar mew-prog-pgp-keys        '(mew-mime-pgp-keys mew-mime-pgp-keys-ext))
 (defvar mew-prog-oasys           nil)
 (defvar mew-prog-octet-stream    'mew-mime-application/octet-stream)
-;; Some broken UAs labels Office files as Application/Octet-Stream
-(defvar mew-prog-msword          '(mew-mime-application/msword
-				   mew-mime-application/msword-ext))
-(defvar mew-prog-msexcel         '(mew-mime-application/msexcel
-				   mew-mime-application/msexcel-ext))
-(defvar mew-prog-mspowerpoint    '(mew-mime-application/mspowerpoint
-				   mew-mime-application/mspowerpoint-ext))
-(defvar mew-prog-visio           'mew-mime-application/octet-stream)
+
+(defvar mew-prog-msword  `(mew-mime-application/msword  ,mew-prog-msword-ext))
+(defvar mew-prog-msexcel `(mew-mime-application/msexcel ,mew-prog-msexcel-ext))
+(defvar mew-prog-mspowerpoint `(mew-mime-application/mspowerpoint ,mew-prog-mspowerpoint-ext))
 (defvar mew-prog-ooffice         "ooffice")
+(defvar mew-prog-visio           'mew-mime-application/octet-stream)
 (defvar mew-prog-mstnef          '(mew-mime-application-ms-tnef
 				   mew-mime-application-ms-tnef-ext))
 (defvar mew-prog-rtf             '(mew-mime-application/rtf
 				   mew-mime-application/rtf-ext))
-
 ;;;
-;;; Text/Html, Application/Xml, Image
+;;; Misc
 ;;;
 
-(defvar mew-format-html "%s.html")
-(defvar mew-format-xml  "%s.xml")
-
-(defvar mew-prog-text/html         'mew-mime-text/html-w3m) ;; See w3m.el
-(defvar mew-prog-text/html-ext     "mozilla")
-(defvar mew-prog-text/html-ext-arg '("-remote" "openFile(%s)")
-  "%s will be replaced with a file name.")
-
-(defvar mew-prog-text/xml         'mew-mime-text/html-w3m) ;; See w3m.el
-(defvar mew-prog-text/xml-ext     "mozilla")
-(defvar mew-prog-text/xml-ext-arg '("-remote" "openFile(%s)")
-  "%s will be replaced with a file name.")
-
-(defvar mew-prog-application/xml         nil)
-(defvar mew-prog-application/xml-ext     "mozilla")
-(defvar mew-prog-application/xml-ext-arg '("-remote" "openFile(%s)")
-  "%s will be replaced with a file name.")
-
-(defvar mew-prog-image/*         'mew-mime-image/*)
-(defvar mew-prog-image/*-ext     "display")
-(defvar mew-prog-image/*-ext-arg '("-geometry" "+0+0"))
-
-(defvar mew-prog-application/msword "wvHtml")
-(defvar mew-prog-application/msexcel "xlhtml")
-(defvar mew-prog-application/mspowerpoint "ppthtml")
-(defvar mew-prog-application/rtf "rtf2html")
-
+(defvar mew-default-external-program nil)
 (defvar mew-dir-list-function 'mew-dir-list-with-link-count)
 
+(defun mew-set-file-type (file) ())
+
 (provide 'mew-unix)
 
 ;;; Copyright Notice:
