@@ -206,6 +206,14 @@ See 'mew-imap-spam-field'."
   :type '(choice (const :tag "Not use" nil)
 		 (string :tag "Spam word")))
 
+(defcustom mew-imap-spam-pattern nil
+  "*IMAP SEARCH pattern to filter spams.
+If non-nil, 'mew-imap-spam-field' and 'mew-imap-spam-field'
+treated as 'nil'."
+  :group 'mew-imap
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Spam word")))
+
 (defcustom mew-imap-spam-folder nil
   "*A folder to be used for IMAP spam filter. 
 See 'mew-imap-spam-field'."
@@ -215,7 +223,7 @@ See 'mew-imap-spam-field'."
 
 ;; must be here
 (defvar mew-basic-folders
-  `(,mew-inbox-folder ,mew-draft-folder ,mew-queue-folder ,mew-postq-folder))
+  (list mew-inbox-folder mew-draft-folder mew-queue-folder mew-postq-folder))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -442,6 +450,30 @@ also 'mew-from'."
   :group 'mew-draft
   :type '(choice (const nil) (repeat string)))
 
+(defcustom mew-my-domains nil
+  "*A list of my domains.
+If addresses on 'mew-draft-address-warning-fields' in a draft
+are not matched to this domain lists, they
+turns the warning color.
+Domains should be downcased."
+  :group 'mew-draft
+  :type '(choice (const nil) (repeat string)))
+
+(defcustom mew-warn-addresses nil
+  "*A list of warning addresses even if it has my domains.
+If addresses on 'mew-draft-address-warning-fields' in a draft
+are matched to this address lists, they turns the warning color.
+Addresses should be downcased."
+  :group 'mew-draft
+  :type '(choice (const nil) (repeat string)))
+
+(defcustom mew-my-address-no-warning nil
+  "*If non-nil, my address in a draft does not
+turn the warning color even if its domain
+is not included 'mew-my-domains'."
+  :group 'mew-draft
+  :type 'boolean)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; 
 ;;; Mail Addresses
@@ -1249,7 +1281,7 @@ if the size is less than 1k byte."
 (defcustom mew-summary-form-size-huge t
   "*If non-nil, the size of message is displayed as 'HUGE'
 when the size is greater than or equal to 1000 after maximum
-quantization by `mew-summary-form-size-unit'."
+quantization by 'mew-summary-form-size-unit'."
   :group 'mew-summary
   :type 'boolean)
 
@@ -1263,11 +1295,11 @@ E.g.
   :type 'string)
 
 (defcustom mew-scan-fields
-  `("Folder:" "Filename:" 
-    ,mew-subj: ,mew-date: ,mew-from: ,mew-to: ,mew-cc:
-    ,mew-ct: ,mew-cte: ,mew-x-mew-uidl:
-    ,mew-message-id: ,mew-in-reply-to: ,mew-references: ,mew-x-mew-ref:
-    ,mew-spam: "Body")
+  (list "Folder:" "Filename:" 
+	mew-subj: mew-date: mew-from: mew-to: mew-cc:
+	mew-ct: mew-cte: mew-x-mew-uidl:
+	mew-message-id: mew-in-reply-to: mew-references: mew-x-mew-ref:
+	mew-spam: "Body")
   "*A list which specifies mewl's output.
 The first element MUST be \"Folder:\".
 The second element MUST be \"Filename:\".
@@ -1289,7 +1321,11 @@ Functions called MEW-FOO will be defined according to this variable.")
 (defvar mew-summary-form-func-prefix "mew-summary-form-"
   "The prefix for symbol used in 'mew-summary-form'.")
 
-(defvar mew-scan-decode-fields `(,mew-subj: ,mew-from: ,mew-to:))
+(defvar mew-scan-decode-fields (list mew-subj: mew-from: mew-to:))
+
+(defvar mew-draft-address-warning-fields
+  (list mew-to: mew-cc: mew-dcc: mew-bcc:
+	mew-resent-to: mew-resent-cc: mew-resent-dcc: mew-resent-bcc:))
 
 (defcustom mew-thread-column 28
   "A position where thread indentation is inserted
@@ -1678,11 +1714,11 @@ are selected out of leaf folders only."
   :group 'mew-refile
   :type 'boolean)
 
-(defcustom mew-use-case-input-completion t
-  "*If non-nil, 'mew-case-input' is automatically completed when you
+(defcustom mew-use-case-completion t
+  "*If non-nil, 'mew-case' is automatically completed when you
 input a folder.  For example, consider that you input a folder in a
 local folder after typing '\\<mew-summary-mode-map>\\[mew-summary-goto-folder]'.  
-Typing '%' automatically inserts 'mew-case-input' before '%'."
+Typing '%' automatically inserts 'mew-case' before '%'."
   :group 'mew-summary
   :type 'boolean)
 
@@ -1697,11 +1733,6 @@ to the right side."
   :group 'mew-summary
   :type 'boolean)
 
-(defcustom mew-use-retrieve t
-  "*If non-nil, '\\<mew-summary-mode-map>\\[mew-summary-retrieve]' can be used."
-  :group 'mew-summary
-  :type 'boolean)
-
 (defcustom mew-use-old-pgp nil
   "*If non-nil, the old fashioned PGP message are used when signing/encrypting.
 Otherwise PGP/MIME is used."
@@ -1871,7 +1902,7 @@ to a region."
 
 (defcustom mew-insert-final-newline t
   "*If *non-nil*, and if text/plain does not have final newline,
-insert a newline at the end of buffer. Due to Emacs 19 and XEmacs bug,
+insert a newline at the end of buffer. Due to XEmacs bug,
 mew-break-pages cannot work without this."
   :group 'mew-message
   :type 'boolean)
@@ -1958,8 +1989,16 @@ See also 'mew-config-alist'."
   :group 'mew-draft
   :type '(choice string (const nil)))
 
+(defcustom mew-bcc nil
+  "*A value inserted into Bcc: field in Draft mode if *non-nil*.
+See also 'mew-config-alist'."
+  :group 'mew-draft
+  :type '(choice string (const nil)))
+
 (defcustom mew-dcc nil
   "*A value inserted into Dcc: field in Draft mode if *non-nil*.
+If the value is 'me, your address is automatically inserted
+according to the case.
 See also 'mew-config-alist'."
   :group 'mew-draft
   :type '(choice string (const nil)))
@@ -2016,7 +2055,7 @@ confirmed to be used."
   :group 'mew-cite
   :type 'boolean)
 
-(defcustom mew-cite-fields `(,mew-from: ,mew-subj: ,mew-date:)
+(defcustom mew-cite-fields (list mew-from: mew-subj: mew-date:)
   "*The fields that you want to extract as citation label. 
 If you change this valuable, you must change mew-cite-format.
 The value of the first field becomes the first argument for mew-cite-format.
@@ -2206,10 +2245,10 @@ in Attachments."
 ;;;
 
 (defcustom mew-fields
-  `(,mew-from: ,mew-to: ,mew-cc: ,mew-dcc: ,mew-fcc: ,mew-bcc: ,mew-subj:
-    ,mew-reply-to: ,mew-followup-to: ,mew-newsgroups: ,mew-distribution:
-    ,mew-resent-from: ,mew-resent-to: ,mew-resent-cc:
-    ,mew-resent-dcc: ,mew-resent-fcc: ,mew-resent-bcc:)
+  (list mew-from: mew-to: mew-cc: mew-dcc: mew-fcc: mew-bcc: mew-subj:
+	mew-reply-to: mew-followup-to: mew-newsgroups: mew-distribution:
+	mew-resent-from: mew-resent-to: mew-resent-cc:
+	mew-resent-dcc: mew-resent-fcc: mew-resent-bcc:)
   "*Completion field list in Draft mode."
   :group 'mew-complete
   :type '(repeat string))
@@ -2244,7 +2283,7 @@ circular domain completion."
 ;;;
 
 (defcustom mew-field-order-for-reediting
-  `(,mew-to: ,mew-newsgroups: ,mew-cc: ,mew-subj: ,mew-from:)
+  (list mew-to: mew-newsgroups: mew-cc: mew-subj: mew-from:)
   "*A field order list for reediting."
   :group 'mew-draft
   :type '(repeat string))
@@ -2254,7 +2293,8 @@ circular domain completion."
 ;;; Fields to be deleted
 ;;;
 
-(defcustom mew-field-delete-common '("From " ">From" "X-Mew")
+(defcustom mew-field-delete-common
+  '("From " ">From" "X-Mew")
   "*A field list to be deleted for reediting/resending/forwarding/saving."
   :group 'mew-draft
   :type '(choice (const nil)
@@ -2264,28 +2304,30 @@ circular domain completion."
 
 (defcustom mew-field-delete-for-reediting
   (or mew-field-delete
-      `(,mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
-	,mew-date: ,mew-message-id: ,mew-mv: "Content-"
-	"Precedence:" ,mew-organization: "X-"
-	"Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:"))
+      (list mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
+	    mew-date: mew-message-id: mew-mv: "Content-"
+	    "Precedence:" mew-organization: "X-"
+	    "Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:"
+	    "DomainKey-Signature:" "Authentication-Results:"))
   "*A field list to be deleted when edit again."
   :group 'mew-draft
   :type '(choice (const nil)
 		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-others
-  `(,mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
-    ,mew-to: ,mew-cc: ,mew-from: ,mew-organization:
-    "Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
+  (list mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
+	mew-to: mew-cc: mew-from: mew-organization:
+	"Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:"
+	"DomainKey-Signature:")
   "*A field list to be deleted when send with different To: and Cc:."
   :group 'mew-draft
   :type '(choice (const nil)
 		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-resending
-  `(,mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
-    "Resent-" "X-Resent-"
-    "Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
+  (list mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
+	"Resent-" "X-Resent-"
+	"Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
   "*A field list to be deleted when resending."
   :group 'mew-draft
   :type '(choice (const nil)
@@ -2305,7 +2347,7 @@ circular domain completion."
 		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-joining
-  `(,mew-mv: ,mew-subj: ,mew-message-id: "Encrypted" "Content-")
+  (list mew-mv: mew-subj: mew-message-id: "Encrypted" "Content-")
   "*A field list to be deleted when joining."
   :group 'mew-summary
   :type '(repeat :tag "Field list" (string :tag "Field")))
@@ -2362,7 +2404,7 @@ on '\\<mew-summary-mode-map>\\[mew-summary-save]'. Otherwise overwrote."
 ;;; Folders
 ;;;
 
-(defcustom mew-regex-folder-candidate "^[^.0-9]\\|^[0-9].*[^0-9]"
+(defcustom mew-regex-folder-candidate "^[^.#0-9]\\|^[0-9].*[^0-9]"
   "*Regular expression used in 'mew-dir-list-with-link-count'
 and 'mew-dir-list-without-link-count' to list up folder
 candidates. The default value \"^[^.0-9]\\|^[0-9].*[^0-9]\" lists up 
@@ -2488,13 +2530,6 @@ Otherwise, the old cases are overridden."
   :group 'mew-draft
   :type 'boolean)
 
-(defcustom mew-case-synchronize t
-  "\\<mew-summary-mode-map>If non-nil, '\\[mew-summary-set-case]' sets both 'mew-case-input' and 'mew-case-output'. 
-If nil, '\\[mew-summary-set-case]' sets 'mew-case-input' only. 
-Use '\\[universal-argument]\\[mew-summary-set-case]' to set 'mew-case-output'."
-  :group 'mew-summary
-  :type 'boolean)
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Temporary files
@@ -2606,13 +2641,13 @@ MODE is one of \"date\" (by chronological order) or
 (defvar mew-range-str-sync   "sync")
 
 (defcustom mew-input-range-list
-  `(,mew-range-str-update ,mew-range-str-all ,mew-range-str-last)
+  (list mew-range-str-update mew-range-str-all mew-range-str-last)
   "*A list used by range completion."
   :group 'mew-complete
   :type '(repeat string))
 
 (defcustom mew-input-range-remote-list
-  `(,mew-range-str-update ,mew-range-str-all ,mew-range-str-last ,mew-range-str-sync)
+  (list mew-range-str-update mew-range-str-all mew-range-str-last mew-range-str-sync)
   "*A list used by range completion."
   :group 'mew-complete
   :type '(repeat string))
@@ -2867,7 +2902,7 @@ your public key as well as receivers' one."
     "x-pgp5-public-key-url:" "x-public-key:"))
    
 (defvar mew-pgp-pks-port "11371")
-(defvar mew-pgp-pks-lang "/pks/lookup?op=get&exact=on&search=")
+(defvar mew-pgp-pks-lang "/pks/lookup?op=get&search=")
 
 ;; Tue Dec 16 16:28:11 JST 2003
 ;; http://pgp.zdv.uni-mainz.de/keyserver/bigbrother/
@@ -2932,9 +2967,6 @@ your public key as well as receivers' one."
 (defvar mew-prog-grep "grep")
 (defvar mew-prog-grep-opts '("-l" "-e"))
 
-(defvar mew-prog-vgrep "grep")
-(defvar mew-prog-vgrep-opts '("-l" "-e"))
-
 (defvar mew-prog-grep-max-msgs 10000)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -2995,6 +3027,15 @@ w3 is used."
 (defvar mew-mode-name-summary "Summary")
 (defvar mew-mode-name-virtual "Virtual")
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Types
+;;;
+
+
+(defvar mew-file-type "MHTX")
+(defvar mew-file-creator "EMAx")
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; For broken MUAs
