@@ -35,6 +35,8 @@
 (defvar mew-w32-prog-print     "notepad.exe")
 (defvar mew-w32-prog-print-arg nil)
 
+(defvar mew-default-external-program mew-w32-exec)
+
 (defvar mew-w32-cs-print nil)
 
 ;; Emacs version dependent variables.
@@ -117,35 +119,35 @@
 
 ;; MIME setting
 
-(defvar mew-prog-plain    '(mew-mime-text/plain mew-mime-text/plain-ext))
+(defvar mew-prog-plain    'mew-mime-text/plain)
 (defvar mew-prog-html     '(mew-mime-text/html mew-mime-text/html-ext))
 (defvar mew-prog-xml      '(mew-mime-text/xml  mew-mime-text/xml-ext))
 (defvar mew-prog-enriched 'mew-mime-text/enriched)
 (defvar mew-prog-text     'mew-mime-text/plain)
-(defvar mew-prog-audio           `(,mew-w32-exec () t))
-(defvar mew-prog-audio2          `(,mew-w32-exec () t)) ;; dummy
+(defvar mew-prog-audio           mew-w32-exec)
+(defvar mew-prog-audio2          mew-w32-exec) ;; dummy
 (defvar mew-prog-image           '(mew-mime-image/* mew-mime-image/*-ext))
-(defvar mew-prog-iges            `(,mew-w32-exec () t))
-(defvar mew-prog-vrml            `(,mew-w32-exec () t))
-(defvar mew-prog-mesh            `(,mew-w32-exec () t))
-(defvar mew-prog-video           `(,mew-w32-exec () t))
+(defvar mew-prog-iges            mew-w32-exec)
+(defvar mew-prog-vrml            mew-w32-exec)
+(defvar mew-prog-mesh            mew-w32-exec)
+(defvar mew-prog-video           mew-w32-exec)
 (defvar mew-prog-rfc822          'mew-mime-message/rfc822)
 (defvar mew-prog-rfc822-headers  'mew-mime-text/rfc822-headers)
 (defvar mew-prog-external-body   '(mew-mime-external-body mew-mime-external-body-ext))
 (defvar mew-prog-delivery-status 'mew-mime-text/plain)
-(defvar mew-prog-postscript      `(,mew-w32-exec () t))
+(defvar mew-prog-postscript      mew-w32-exec)
 (defvar mew-prog-pgp-keys        '(mew-mime-pgp-keys mew-mime-pgp-keys-ext))
-(defvar mew-prog-pdf             `(,mew-w32-exec () t))
+(defvar mew-prog-pdf             mew-w32-exec)
 (defvar mew-prog-xml2            '(mew-mime-application/xml
 				   mew-mime-application/xml-ext))
-(defvar mew-prog-oasys           `(,mew-w32-exec () t))
-(defvar mew-prog-octet-stream    `(,mew-w32-exec () t))
-(defvar mew-prog-msword          `(,mew-w32-exec () t))
-(defvar mew-prog-msexcel         `(,mew-w32-exec () t))
-(defvar mew-prog-mspowerpoint    `(,mew-w32-exec () t))
-(defvar mew-prog-visio           `(,mew-w32-exec () t))
-(defvar mew-prog-ooffice         `(,mew-w32-exec () t))
-(defvar mew-prog-rtf             `(,mew-w32-exec () t))
+(defvar mew-prog-oasys           mew-w32-exec)
+(defvar mew-prog-octet-stream    mew-w32-exec)
+(defvar mew-prog-msword          mew-w32-exec)
+(defvar mew-prog-msexcel         mew-w32-exec)
+(defvar mew-prog-mspowerpoint    mew-w32-exec)
+(defvar mew-prog-visio           mew-w32-exec)
+(defvar mew-prog-ooffice         mew-w32-exec)
+(defvar mew-prog-rtf             mew-w32-exec)
 
 ;;;
 ;;; Text/Html, Application/Xml, Image
@@ -154,21 +156,17 @@
 (defvar mew-format-html "%s.htm")
 (defvar mew-format-xml  "%s.xml")
 
-(defvar mew-prog-text/html         'mew-mime-text/html-w3m) ;; See w3m.el
-(defvar mew-prog-text/html-ext     mew-w32-exec)
-(defvar mew-prog-text/html-ext-arg nil)
+(defvar mew-prog-text/html           'mew-mime-text/html-w3m) ;; See w3m.el
+(defvar mew-prog-text/html-ext       mew-w32-exec)
 
-(defvar mew-prog-text/xml         'mew-mime-text/html-w3m) ;; See w3m.el
-(defvar mew-prog-text/xml-ext     mew-w32-exec)
-(defvar mew-prog-text/xml-ext-arg nil)
+(defvar mew-prog-text/xml            'mew-mime-text/html-w3m) ;; See w3m.el
+(defvar mew-prog-text/xml-ext        mew-w32-exec)
 
-(defvar mew-prog-application/xml         nil)
-(defvar mew-prog-application/xml-ext     mew-w32-exec)
-(defvar mew-prog-application/xml-ext-arg nil)
+(defvar mew-prog-application/xml     nil)
+(defvar mew-prog-application/xml-ext mew-w32-exec)
 
 (defvar mew-prog-image/*         'mew-mime-image/*)
 (defvar mew-prog-image/*-ext     mew-w32-exec)
-(defvar mew-prog-image/*-ext-arg nil)
 
 (defvar mew-prog-application/msword nil)
 (defvar mew-prog-application/msexcel nil)
@@ -184,6 +182,31 @@
 
 (defvar mew-dir-list-function 'mew-dir-list-without-link-count)
 
+(defun mew-draft-dnd-for-meadow (event)
+  (interactive "e")
+  (when (eq (posn-window (event-start event)) (selected-window))
+    (let ((files (car (cdr (cdr event))))
+	  from to)
+      (if (stringp files)
+	  (setq files (list files)))
+      (while (setq from (car files))
+	(setq files (cdr files))
+	(setq from (dos-to-unix-filename from))
+	(when (file-exists-p from)
+	  (setq to (file-name-nondirectory from))
+	  (unless (mew-attach-p)
+	    (mew-draft-prepare-attachments))
+	  (goto-char (point-max))
+	  (forward-line -2)
+	  (mew-attach-next)
+	  (cond
+	   ((file-directory-p from)
+	    (message "Directory cannot be attached"))
+	   (t
+	    (mew-attach-copy from to))))))))
+
+(defun mew-set-file-type (file) ())
+
 (provide 'mew-win32)
 
 ;;; Copyright Notice:
